@@ -80,6 +80,10 @@
 #   define NV_QNX
 #endif
 
+#if (defined(__ANDROID__) || defined(ANDROID)) && !defined(NV_ANDROID)
+#   define NV_ANDROID
+#endif
+
 /* ***** Apple variations */
 #if defined(macintosh) || defined(__APPLE__)
 #   define NV_MACINTOSH
@@ -248,11 +252,31 @@
 #else
 #define NVOS_IS_UNIX 0
 #endif
+#if defined(NV_BSD)
+#define NVOS_IS_FREEBSD 1
+#else
+#define NVOS_IS_FREEBSD 0
+#endif
+#if defined(NV_SUNOS)
+#define NVOS_IS_SOLARIS 1
+#else
+#define NVOS_IS_SOLARIS 0
+#endif
+#if defined(NV_VMWARE)
+#define NVOS_IS_VMWARE 1
+#else
+#define NVOS_IS_VMWARE 0
+#endif
 #if defined(NV_QNX)
 #define NVOS_IS_QNX 1
 #else
 #define NVOS_IS_QNX 0
 #endif
+#if defined(NV_ANDROID)
+#define NVOS_IS_ANDROID 1
+#else
+#define NVOS_IS_ANDROID 0
+#endif
 #if defined(NV_MACINTOSH)
 #define NVOS_IS_MACINTOSH 1
 #else
