@@ -24,6 +24,8 @@
 *                                                                           *
 \***************************************************************************/
 
+#include <stdarg.h>
+
 /*
  * Define away Microsoft compiler extensions when possible
  */
@@ -82,7 +84,7 @@ char*       NV_API_CALL  os_string_copy              (char *, const char *);
 RM_STATUS   NV_API_CALL  os_strncpy_from_user        (char *, const char *, NvU32);
 NvU32       NV_API_CALL  os_string_length            (const char *);
 NvS32       NV_API_CALL  os_snprintf                 (char *, NvU32, const char *, ...);
-void        NV_API_CALL  os_log_error                (NvU32, NvU32, const char *, void *);
+void        NV_API_CALL  os_log_error                (NvU32, NvU32, const char *, va_list);
 NvU8*       NV_API_CALL  os_mem_copy                 (NvU8 *, const NvU8 *, NvU32);
 RM_STATUS   NV_API_CALL  os_memcpy_from_user         (void *, const void *, NvU32);
 RM_STATUS   NV_API_CALL  os_memcpy_to_user           (void *, const void *, NvU32);
@@ -131,6 +133,8 @@ RM_STATUS   NV_API_CALL  os_cond_acquire_sema        (void *);
 RM_STATUS   NV_API_CALL  os_release_sema             (void *);
 BOOL        NV_API_CALL  os_is_acquired_sema         (void *);
 RM_STATUS   NV_API_CALL  os_schedule                 (void);
+RM_STATUS   NV_API_CALL  os_alloc_spinlock           (void **);
+void        NV_API_CALL  os_free_spinlock            (void *);
 NvU64       NV_API_CALL  os_acquire_spinlock         (void *);
 void        NV_API_CALL  os_release_spinlock         (void *, NvU64);
 RM_STATUS   NV_API_CALL  os_get_address_space_info   (NvU64 *, NvU64 *, NvU64 *, NvU64 *);
@@ -149,6 +153,7 @@ RM_STATUS   NV_API_CALL  os_acquire_semaphore        (void *);
 RM_STATUS   NV_API_CALL  os_release_semaphore        (void *);
 BOOL        NV_API_CALL  os_semaphore_may_sleep      (void);
 RM_STATUS   NV_API_CALL  os_get_version_info         (os_version_info*);
+BOOL        NV_API_CALL  os_is_isr                   (void);
 
 /* BOOL os_pat_supported(void) 
  * report to core resman whether pat is supported for marking cache attributes
